<?php
/* --------------------------------------------------------------
  ContentZoneStylingTrait.php 2019-07-11
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2019 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------*/

namespace Gambio\StyleEdit\Core\Components\ContentZone\Entities\Traits;

use Gambio\StyleEdit\Core\Components\BackgroundGroup\Entities\BackgroundGroupOption;
use Gambio\StyleEdit\Core\Components\BorderGroup\Entities\BorderGroupOption;
use Gambio\StyleEdit\Core\Components\FontGroup\Entities\FontGroupOption;
use Gambio\StyleEdit\Core\Components\MarginGroup\Entities\MarginGroupOption;
use Gambio\StyleEdit\Core\Components\PaddingGroup\Entities\PaddingGroupOption;

/**
 * Trait ContentZoneStylingTrait
 */
trait ContentZoneStylingTrait
{
    /**
     * @param BackgroundGroupOption $background
     *
     * @return string
     */
    protected function getBackgroundStyle(BackgroundGroupOption $background): string
    {
        $style = '';
        
        if ($background->gradient()->enabled()->value()) {
            
            $gradientColor1 = $background->gradient()->color1()->value();
            $gradientColor2 = $background->gradient()->color2()->value();
            $gradientType   = $background->gradient()->gradientType()->value();
            $gradientAngle  = $background->gradient()->angle()->value();
            
            $style .= "background: $gradientColor1;" . PHP_EOL;
            $style .= "background: -moz-$gradientType-gradient($gradientAngle, $gradientColor1 0%, $gradientColor2 100%);"
                      . PHP_EOL;
            $style .= "background: -webkit-$gradientType-gradient($gradientAngle, $gradientColor1 0%,$gradientColor2 100%);"
                      . PHP_EOL;
            $style .= "background: $gradientType-gradient($gradientAngle, $gradientColor1 0%,$gradientColor2 100%);"
                      . PHP_EOL;
        } else {
            $style .= 'background-color: ' . $background->color()->value() . ';' . PHP_EOL;
        }
        
        if ($background->image()->enabled()->value()) {
            
            $style .= 'background-image: url(\'' . $background->image()->url()->value() . "');" . PHP_EOL;
            $style .= 'background-position: ' . $background->image()->position()->value() . ';' . PHP_EOL;
            $style .= 'background-repeat: ' . $background->image()->repeat()->value() . ';' . PHP_EOL;
            $style .= 'background-size: ' . $background->image()->size()->value() . ';' . PHP_EOL;
            $style .= 'background-attachment: ' . $background->image()->attachment()->value() . ';' . PHP_EOL;
        }
        
        return $style;
    }
    
    
    /**
     * @param MarginGroupOption $margin
     *
     * @return string
     */
    protected function getMargin(MarginGroupOption $margin): string
    {
        return 'margin: ' . $margin->marginTop()->value() . ' ' . $margin->marginRight()->value() . ' '
               . $margin->marginBottom()->value() . ' ' . $margin->marginLeft()->value() . ';';
    }
    
    
    /**
     * @param PaddingGroupOption $padding
     *
     * @return string
     */
    protected function getPadding(PaddingGroupOption $padding): string
    {
        return 'padding: ' . $padding->paddingTop()->value() . ' ' . $padding->paddingRight()->value() . ' '
               . $padding->paddingBottom()->value() . ' ' . $padding->paddingLeft()->value() . ';' . PHP_EOL;
    }
    
    
    /**
     * @param BorderGroupOption $border
     *
     * @return string
     */
    protected function getBorder(BorderGroupOption $border): string
    {
        $style = '';
        
        $style .= 'border-top-width: ' . $border->top()->value() . ';' . PHP_EOL;
        $style .= 'border-right-width: ' . $border->right()->value() . ';' . PHP_EOL;
        $style .= 'border-bottom-width: ' . $border->bottom()->value() . ';' . PHP_EOL;
        $style .= 'border-left-width: ' . $border->left()->value() . ';' . PHP_EOL;
        $style .= 'border-style: ' . $border->style()->value() . ';' . PHP_EOL;
        $style .= 'border-color: ' . $border->color()->value() . ';' . PHP_EOL;
        
        return $style;
    }
    
    
    /**
     * @param string               $colId
     * @param FontGroupOption|null $font
     *
     * @return string
     */
    protected function getCss(string $colId, FontGroupOption $font = null): string
    {
        $styling = '';
        
        $styling .= $this->getBorder($this->border);
        $styling .= $this->getBackgroundStyle($this->background);
        $styling .= $this->getPadding($this->padding);
        $styling .= $this->getMargin($this->margin);
        
        if ($font !== null) {
            
            $styling .= $this->getFontStyle($font);
        }
        
        $style = '<style>' . PHP_EOL . "\t#$colId {";
        
        foreach (explode(PHP_EOL, $styling) as $css) {
            
            $style .= PHP_EOL . "\t\t$css";
        }
        
        return $style . PHP_EOL . "\t}" . PHP_EOL . '</style>';
    }
    
    
    /**
     * @param FontGroupOption $font
     *
     * @return string
     */
    protected function getFontStyle(FontGroupOption $font): string
    {
        $style = '';
        $style .= 'font-family: ' . $font->family()->value() . ';' . PHP_EOL;
        $style .= 'font-size: ' . $font->size()->value() . ';' . PHP_EOL;
        $style .= 'font-style: ' . $font->style()->value() . ';' . PHP_EOL;
        $style .= 'text-align: ' . $font->textAlign()->value() . ';' . PHP_EOL;
        
        if ($font->textDecorationUnderline()) {
            
            $style .= "text-decoration: underline;" . PHP_EOL;
        }
        
        if ($font->textTransformUppercase()) {
            
            $style .= "text-transform: uppercase;" . PHP_EOL;
        }
        
        return $style;
    }
}