<?php
/* --------------------------------------------------------------
  HeadlineWidget.php 2019-07-16
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2019 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------*/

use Gambio\StyleEdit\Core\Components\Checkbox\Entities\CheckboxOption;
use Gambio\StyleEdit\Core\Components\FontGroup\Entities\FontGroupOption;
use Gambio\StyleEdit\Core\Components\Style\CssGenerator;
use Gambio\StyleEdit\Core\Components\TextBox\Entities\TextBox;
use Gambio\StyleEdit\Core\Language;
use Gambio\StyleEdit\Core\Options\Entities\FieldSet;
use Gambio\StyleEdit\Core\Widgets\Abstractions\AbstractWidget;
use Gambio\StyleEdit\Core\Widgets\Abstractions\Interfaces\ContentGeneratorInterface;

/**
 * Class HeadlineWidget
 */
class HeadlineWidget extends AbstractWidget
{
    /**
     * @var string
     */
    protected $headingType = 'h3';
    
    /**
     * @var string
     */
    protected $text = 'Heading';
    
    /**
     * @var FontGroupOption
     */
    protected $font;
    
    
    /**
     * produces the widget HTML output
     *
     * @param Language|null $currentLanguage
     *
     * @return string
     */
    public function htmlContent(?Language $currentLanguage) : string
    {
        $html = $this->htmlTemplate($currentLanguage);
        $html = str_replace(
            ['{headingType}', '{text}', '{id}'],
            [
                $this->headingType->value($currentLanguage),
                $this->text->value($currentLanguage),
                $this->id->value($currentLanguage)
            ],
            $html
        );
        
        if ($this->font !== null) {
            
            if ($this->font->enableCustomization()->value($currentLanguage) === true) {
                
                $style = (string)CssGenerator::create($this->id->value($currentLanguage))->setFont($this->font);
            } else {
                
                $style = '';
            }
            
            $html = $style . PHP_EOL . $html;
        }
        
        return $html;
    }
    
    
    /**
     * @return string
     */
    protected function htmlTemplate() : string
    {
        return '<{headingType} id="{id}">{text}</{headingType}>';
    }
    
    
    /**
     * Specify data which should be serialized to JSON
     * @link  https://php.net/manual/en/jsonserializable.jsonserialize.php
     * @return mixed data which can be serialized by <b>json_encode</b>,
     * which is a value of any type other than a resource.
     * @since 5.4.0
     */
    public function jsonSerialize()
    {
        $result            = $this->jsonObject;
        $result->type      = 'headline';
        $result->id        = $this->static_id;
        $result->fieldsets = $this->fieldsets;
        
        return $result;
    }
    
}